@@ -1,11 +1,9 @@
 {-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE TypeApplications #-}
 
 module Control.Carrier.Logger.IOSpec (
   spec,
 ) where
 
-import Control.Exception (try, IOException)
 import Control.Carrier.Lift (runM)
 import Control.Carrier.Logger.IO (runLoggerIO, singleHandle)
 import Control.Monad.Logger (logDebugN, logInfoN, logWarnN)
@@ -19,7 +17,7 @@ spec = do
         (fp, h) <- openTempFile "." "LoggerIOC.log"
         _ <- runM (runLoggerIO (singleHandle h) action)
         hClose h
-        readFile fp <* (try @IOException (removePathForcibly fp))
+        readFile fp <* removePathForcibly fp
 
   describe "LoggerIOC" $ do
     it "no log" $ do
